<?php
/**
 * FuzeWorks Authentication Plugin.
 *
 * The FuzeWorks PHP FrameWork
 *
 * Copyright (C) 2013 - 2023 i15
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * @author    i15
 * @copyright Copyright (C) 2013 - 2023, i15. (https://i15.nl)
 * @license   https://opensource.org/licenses/MIT MIT License
 *
 * @since Version 1.3.0
 *
 * @version Version 1.3.0
 */

namespace FuzeWorks\Authentication;

use Tracy\Debugger;
use Tracy\IBarPanel;

/**
 * AuthenticationTracyBridge Class.
 *
 * Integrates the AuthenticationPlugin with the bottom development panel provided by Nette Tracy.
 *
 * It creates a small icon on the development bar, with info on the current session.
 */
class AuthenticationTracyBridge implements IBarPanel
{

    /**
     * @var AuthenticationPlugin $plugin
     */
    protected AuthenticationPlugin $plugin;

    public function __construct(AuthenticationPlugin $plugin)
    {
        $this->plugin = $plugin;
        $bar = Debugger::getBar();
        $bar->addPanel($this);
    }

    /**
     * @inheritDoc
     */
    function getTab(): string
    {
        $session = $this->plugin->sessions->getCurrentSession();
        ob_start();
        require(dirname(__DIR__, 3) . DS . "layout" . DS . "bridge" . DS . "layout.authtab.php");
        return ob_get_clean();
    }

    /**
     * @inheritDoc
     */
    function getPanel(): string
    {
        $session = $this->plugin->sessions->getCurrentSession();
        ob_start();
        require(dirname(__DIR__, 3) . DS . "layout" . DS . "bridge" . DS . "layout.authpanel.php");
        return ob_get_clean();
    }
}