<?php
/**
 * FuzeWorks Authentication Plugin.
 *
 * The FuzeWorks PHP FrameWork
 *
 * Copyright (C) 2013 - 2023 i15
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * @author    i15
 * @copyright Copyright (C) 2013 - 2023, i15. (https://i15.nl)
 * @license   https://opensource.org/licenses/MIT MIT License
 *
 * @since Version 1.3.0
 *
 * @version Version 1.3.0
 */

namespace FuzeWorks\Authentication\Model;

class Session
{

    /**
     * The User this Session pertains to.
     *
     * @var User
     */
    public User $user;

    /**
     * A 16 character random string identifying this Session.
     *
     * @var string
     */
    public string $sessionKey;

    /**
     * A unix int timestamp when the session will expire.
     *
     * @var int
     */
    public int $expiryDate;

    /**
     * A unix int timestamp after which, but before the $expiryDate, a session will be extended.
     *
     * @var int
     */
    public int $expiryThreshold;

    /**
     * How long a session should last. If false, sessions should only last an hour. If true, sessions should last 3 months.
     *
     * @var bool
     */
    public bool $persistent;

    /**
     * Other data describing context of the Session, such as User-Agent and IP.
     *
     * @var array
     */
    public array $context;

    /**
     * Whether this session is active or not.
     *
     * If false, the user shall be logged out automatically.
     *
     * @var bool
     */
    public bool $active;

    /**
     * Data about this session stored in ObjectStorage
     *
     * @var array
     */
    protected array $sessionData;

    public function __construct(User $user, string $sessionKey, int $expiryDate, int $expiryThreshold, array $context, bool $persistent = false, bool $active = true)
    {
        $this->user = $user;
        $this->sessionKey = $sessionKey;
        $this->expiryDate = $expiryDate;
        $this->expiryThreshold = $expiryThreshold;
        $this->context = $context;
        $this->persistent = $persistent;
        $this->active = $active;
    }

    /**
     * Returns true if the user of this session has access to a specific permission node.
     *
     * @param string $permissionString
     * @return bool
     */
    public function hasPermission(string $permissionString): bool
    {
        return $this->user->hasPermission($permissionString);
    }

}