<?php
/**
 * FuzeWorks Authentication Plugin.
 *
 * The FuzeWorks PHP FrameWork
 *
 * Copyright (C) 2013 - 2023 i15
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * @author    i15
 * @copyright Copyright (C) 2013 - 2023, i15. (https://i15.nl)
 * @license   https://opensource.org/licenses/MIT MIT License
 *
 * @since Version 1.3.0
 *
 * @version Version 1.3.0
 */

namespace FuzeWorks\Authentication;

use FuzeWorks\Authentication\Exceptions\InputException;
use FuzeWorks\Authentication\Model\User;
use FuzeWorks\DatabaseEngine\iDatabaseEngine;

interface UsersModelDriverInterface
{

    /**
     * Initializes the model.
     *
     * Should only require the provided Database Engine.
     *
     * @param iDatabaseEngine $engine
     */
    public function __construct(iDatabaseEngine $engine);

    /**
     * Add a new Session to the database using the provided User object.
     *
     * @param User[] $users
     * @return bool
     */
    public function createUsers(array $users): bool;

    /**
     * Return a list of User[] from the database on the basis of the provided search filter.
     *
     * @return User[]
     */
    public function readUsers(array $filter, array $options = []): array;

    /**
     * Update a list of User[] in the database on the basis of the provided User[] objects.
     *
     * @param User[] $users
     * @return bool
     */
    public function updateUsers(array $users): bool;

    /**
     * Delete the provided User[] objects from the database.
     *
     * @param User[] $users
     * @return bool
     */
    public function deleteUsers(array $users): bool;

}